import { select, 
        json, 
        geoPath, 
        geoNaturalEarth1, 
        zoom, 
        event,
        scaleOrdinal,
        schemeSpectral } from 'd3';
import { loadAndProcessData } from './loadAndProcessData'
import { colorLegend } from './colorLegend'

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection)

const g = svg.append('g')

const colorLegendG = svg.append('g')
	.attr('transform', `translate(30, 325)`);

g.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({type: 'Sphere'}))

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}))

const colorScale = scaleOrdinal();

const economyFormatter = d => d.substring(3);

const colorValue = d => economyFormatter(d.properties.economy);

loadAndProcessData().then(countries => {
  
  // Will have to replicate the logic here
  // since we want to use the default sort function
  colorScale
    .domain(countries.features.map(d => d.properties.economy))
  	.domain(colorScale.domain()
            								.sort()
            								.map(economyFormatter)
                            .reverse())
  	.range(schemeSpectral[colorScale.domain().length]);
  
  colorLegendG.call(colorLegend, {
    colorScale, 
    circleRadius: 8,
    spacing: 25,
  	textOffset: 20,
    backgroundRectWidth: 250
	});
  
	g.selectAll('path')
    .data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => colorScale(colorValue(d)))
    .append('title')
      .text(d => d.properties.name + ' - ' + colorValue(d))
})
